@@ -21,7 +21,7 @@
 #include "Python.h"
 #include <math.h>
 
-#define PYO_VERSION "0.8.8"
+#define PYO_VERSION "0.9.0"
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -520,6 +520,12 @@ extern PyTypeObject LogiMapType;
 extern PyTypeObject SharedTableType;
 extern PyTypeObject TableFillType;
 extern PyTypeObject TableScanType;
+extern PyTypeObject HRTFDataType;
+extern PyTypeObject HRTFSpatterType;
+extern PyTypeObject HRTFType;
+extern PyTypeObject ExpandType;
+extern PyTypeObject RMSType;
+extern PyTypeObject MidiLinsegType;
 
 /* Constants */
 #define E M_E
