@@ -65,6 +65,8 @@ from pyolib.phasevoc import *
 from pyolib._core import *
 from pyolib.wxgui import *
 import pyolib.wxgui as wxgui
+from pyolib.hrtf import *
+import pyolib.hrtf as hrtf
 if WITH_EXTERNALS:
     import pyolib.external as external
     from pyolib.external import *
@@ -104,14 +106,15 @@ OBJECTS_TREE = {
         'PyoObject': {
             'analysis': sorted(['Follower', 'Follower2', 'ZCross', 'Yin', 
                                 'Centroid', 'AttackDetector', 'Scope',
-                                'Spectrum', 'PeakAmp']),
+                                'Spectrum', 'PeakAmp', 'RMS']),
             'arithmetic': sorted(['Sin', 'Cos', 'Tan', 'Abs', 'Sqrt', 'Log', 
                                   'Log2', 'Log10', 'Pow', 'Atan2', 'Floor',
                                   'Round', 'Ceil', 'Tanh', 'Exp']),
             'controls': sorted(['Fader', 'Sig', 'SigTo', 'Adsr', 'Linseg', 
                                 'Expseg']),
             'dynamics': sorted(['Clip', 'Compress', 'Degrade', 'Mirror', 
-                                'Wrap', 'Gate', 'Balance', 'Min', 'Max']),
+                                'Wrap', 'Gate', 'Balance', 'Min', 'Max',
+                                'Expand']),
             'effects': sorted(['Delay', 'SDelay', 'Disto', 'Freeverb', 
                                'Waveguide', 'Convolve', 'WGVerb', 'SmoothDelay',
                                'Harmonizer', 'Chorus', 'AllpassWG', 'FreqShift', 
@@ -129,11 +132,11 @@ OBJECTS_TREE = {
             'internals': sorted(['Dummy', 'InputFader', 'Mix', 'VarPort']),
             'midi': sorted(['Midictl', 'CtlScan', 'CtlScan2', 'Notein', 
                             'MidiAdsr', 'MidiDelAdsr', 'Bendin', 'Touchin', 
-                            'Programin', 'RawMidi']),
+                            'Programin', 'RawMidi', 'MidiLinseg']),
             'opensndctrl': sorted(['OscReceive', 'OscSend', 'OscDataSend', 
                                    'OscDataReceive', 'OscListReceive']),
             'pan': sorted(['Pan', 'SPan', 'Switch', 'Selector', 'Mixer', 
-                           'VoiceManager']),
+                           'VoiceManager', 'HRTF']),
             'pattern': sorted(['Pattern', 'Score', 'CallAfter']),
             'randoms': sorted(['Randi', 'Randh', 'Choice', 'RandInt', 'Xnoise', 
                                'XnoiseMidi', 'RandDur', 'XnoiseDur', 'Urn',
