@@ -59,6 +59,7 @@ void jack_ctlout(Server *self, int ctlnum, int value, int chan, long timestamp)
 void jack_programout(Server *self, int value, int chan, long timestamp) {};
 void jack_pressout(Server *self, int value, int chan, long timestamp) {};
 void jack_bendout(Server *self, int value, int chan, long timestamp) {};
+void jack_makenote(Server *self, int pit, int vel, int dur, int chan) {};
 
 #endif
 
@@ -84,6 +85,7 @@ void pm_programout(Server *self, int value, int chan, long timestamp) {};
 void pm_pressout(Server *self, int value, int chan, long timestamp) {};
 void pm_bendout(Server *self, int value, int chan, long timestamp) {};
 void pm_sysexout(Server *self, unsigned char *msg, long timestamp) {};
+void pm_makenote(Server *self, int pit, int vel, int dur, int chan) {};
 long pm_get_current_time() { return 0; };
 #endif
 
@@ -534,8 +536,7 @@ Server_traverse(Server *self, visitproc visit, void *arg)
     Py_VISIT(self->TIME);
     if (self->CALLBACK != NULL)
         Py_VISIT(self->CALLBACK);
-    if (PyList_Size(self->streams) > 0)
-        Py_VISIT(self->streams);
+    Py_VISIT(self->streams);
     Py_VISIT(self->jackInputPortNames);
     Py_VISIT(self->jackOutputPortNames);
     Py_VISIT(self->jackMidiInputPortName);
@@ -554,8 +555,7 @@ Server_clear(Server *self)
     Py_CLEAR(self->TIME);
     if (self->CALLBACK != NULL)
         Py_CLEAR(self->CALLBACK);
-    if (PyList_Size(self->streams) > 0)
-        Py_CLEAR(self->streams);
+    Py_CLEAR(self->streams);
     Py_CLEAR(self->jackInputPortNames);
     Py_CLEAR(self->jackOutputPortNames);
     Py_CLEAR(self->jackMidiInputPortName);
@@ -621,6 +621,7 @@ Server_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->serverName = (char *) calloc(32, sizeof(char));
     self->jackautoin = 1;
     self->jackautoout = 1;
+    self->streams = PyList_New(0);
     self->jackInputPortNames = PY_BYTES_FROM_STRING("");
     self->jackOutputPortNames = PY_BYTES_FROM_STRING("");
     self->jackMidiInputPortName = PY_BYTES_FROM_STRING("");
@@ -1306,6 +1307,16 @@ Server_shutdown(Server *self)
         Server_error(self, "Error closing audio backend.\n");
     }
 
+    /* Cleaning list of audio streams. */
+    PyGILState_STATE s = PyGILState_Ensure();
+    if (PyList_Size(self->streams) > 0) {
+        for (i=PyList_Size(self->streams); i>0; i--) {
+            PySequence_DelItem(self->streams, i-1);
+        }
+    }
+    self->stream_count = 0;
+    PyGILState_Release(s);
+
     Py_RETURN_NONE;
 }
 
@@ -1334,7 +1345,8 @@ Server_boot(Server *self, PyObject *arg)
         Server_error(self, "The argument to set for a new buffer must be a boolean.\n");
     }
 
-    self->streams = PyList_New(0);
+    Server_debug(self, "Server_boot: streams list size (must always be 0): %d\n",
+                 PyList_Size(self->streams));
     switch (self->audio_be_type) {
         case PyoPortaudio:
             audioerr = Server_pa_init(self);
@@ -1916,6 +1928,29 @@ Server_sysexout(Server *self, PyObject *args)
     Py_RETURN_NONE;
 }
 
+PyObject *
+Server_makenote(Server *self, PyObject *args)
+{
+    int pit, vel, dur, chan;
+
+    if (! PyArg_ParseTuple(args, "iiii", &pit, &vel, &dur, &chan))
+        return PyInt_FromLong(-1);
+
+    switch (self->midi_be_type) {
+        case PyoPortmidi:
+            if (self->withPortMidiOut) {
+                pm_makenote(self, pit, vel, dur, chan);
+            }
+            break;
+        case PyoJackMidi:
+            jack_makenote(self, pit, vel, dur, chan);
+            break;
+        default:
+            break;
+    }
+    Py_RETURN_NONE;
+}
+
 MYFLT *
 Server_getInputBuffer(Server *self) {
     return (MYFLT *)self->input_buffer;
@@ -2218,6 +2253,7 @@ static PyMethodDef Server_methods[] = {
     {"pressout", (PyCFunction)Server_pressout, METH_VARARGS, "Send a channel pressure event to Portmidi output stream."},
     {"bendout", (PyCFunction)Server_bendout, METH_VARARGS, "Send a pitch bend event to Portmidi output stream."},
     {"sysexout", (PyCFunction)Server_sysexout, METH_VARARGS, "Send a system exclusive message to midi output stream."},
+    {"makenote", (PyCFunction)Server_makenote, METH_VARARGS, "Send a Midi noteon event followed by its corresponding noteoff event."},
     {"addMidiEvent", (PyCFunction)Server_addMidiEvent, METH_VARARGS, "Add a midi event manually (without using portmidi callback)."},
     {"getStreams", (PyCFunction)Server_getStreams, METH_NOARGS, "Returns the list of streams added to the server."},
     {"getSamplingRate", (PyCFunction)Server_getSamplingRate, METH_NOARGS, "Returns the server's sampling rate."},
